Summary: A TLS protocol implementation
Name: gnutls
Version: 2.6.6
Release: 1
License: LGPL
Group: System Environment/Libraries
URL: http://www.gnutls.org/
Source0: ftp://ftp.gnutls.org/pub/%{name}/%{name}-%{version}.tar.bz2
Source1: ftp://ftp.gnutls.org/pub/%{name}/%{name}-%{version}.tar.bz2.sig
Patch0: %{name}-%{version}-aix.patch
BuildRequires: libgcrypt-devel >= 1.2.4, gettext-devel >= 0.17
BuildRequires: zlib-devel, libtasn1-devel, lzo-devel
BuildRequires: readline-devel >= 5.2
Requires: libgcrypt >= 1.2.4, gettext >= 0.17
Requires: zlib, libtasn1, lzo
Requires: readline >= 5.2

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

%description
GnuTLS is a project that aims to develop a library which provides a secure 
layer, over a reliable transport layer. Currently the GnuTLS library implements
the proposed standards by the IETF's TLS working group.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Development files for the %{name} package.
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: libgcrypt-devel, zlib-devel
Requires: libtasn1-devel, lzo-devel
Requires: pkg-config, info, gettext-devel >= 0.17
Requires: /sbin/install-info

%description devel
GnuTLS is a project that aims to develop a library which provides a secure
layer, over a reliable transport layer. Currently the GnuTLS library implements
the proposed standards by the IETF's TLS working group.
This package contains files needed for developing applications with
the GnuTLS library.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc -q64" or "gcc -maix64".


%package utils
Summary: Command line tools for TLS protocol.
Group: Applications/System
Requires: %{name} = %{version}-%{release}

%description utils
GnuTLS is a project that aims to develop a library which provides a secure
layer, over a reliable transport layer. Currently the GnuTLS library implements
the proposed standards by the IETF's TLS working group.
This package contains command line TLS client and server and certificate
manipulation tools.


%prep
%setup -q
%patch0 -p0


%build
# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"
export NM="nm -X32_64"

# first build the 64-bit version
export CC="xlc -q64"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --infodir=%{_infodir} \
    --enable-shared --enable-static \
    --with-lzo \
    --disable-cxx
make %{?_smp_mflags}

cp libextra/.libs/libgnutls-extra.so.26 .
cp libextra/.libs/libgnutls-openssl.so.26 .
cp lib/.libs/libgnutls.so.26 .

make distclean

# now build the 32-bit version
export CC="xlc"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --infodir=%{_infodir} \
    --enable-shared --enable-static \
    --with-lzo \
    --disable-cxx
make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
make DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
export AR="ar -X32_64"
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/libgnutls-extra.a ./libgnutls-extra.so.26
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/libgnutls-openssl.a ./libgnutls-openssl.so.26
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/libgnutls.a ./libgnutls.so.26

cd doc
make DESTDIR=${RPM_BUILD_ROOT} install

rm -f ${RPM_BUILD_ROOT}%{_infodir}/dir
gzip --best ${RPM_BUILD_ROOT}%{_infodir}/*.info*

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%post devel
/sbin/install-info %{_infodir}/%{name}.info.gz %{_infodir}/dir || :


%preun devel
if [ $1 -eq 0 ]; then
    /sbin/install-info --delete %{_infodir}/%{name}.info.gz %{_infodir}/dir || :
fi


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%{_libdir}/*.a
%{_datadir}/locale/*
%doc AUTHORS COPYING COPYING.LIB README
/usr/lib/*.a


%files devel
%defattr(-,root,system,-)
%{_bindir}/libgnutls*-config
%{_includedir}/*
%{_libdir}/*.la
%{_libdir}/pkgconfig/*.pc
%{_datadir}/aclocal/*
%{_mandir}/man3/*
%{_infodir}/%{name}*
/usr/bin/libgnutls*-config
/usr/include/*
/usr/lib/*.la


%files utils
%defattr(-,root,system,-)
%{_bindir}/certtool
%{_bindir}/%{name}*
%{_bindir}/psktool
%{_bindir}/srptool
%{_mandir}/man1/*
/usr/bin/certtool
/usr/bin/%{name}*
/usr/bin/psktool
/usr/bin/srptool


%changelog
* Fri Jun 05 2009 Michael Perzl <michael@perzl.org> - 2.6.6-1
- updated to version 2.6.6

* Tue Mar 10 2009 Michael Perzl <michael@perzl.org> - 2.6.4-1
- updated to version 2.6.4

* Sat Nov 08 2008 Michael Perzl <michael@perzl.org> - 2.6.0-1
- updated to version 2.6.0

* Sat Nov 08 2008 Michael Perzl <michael@perzl.org> - 2.4.2-1
- updated to version 2.4.2

* Wed Oct 01 2008 Michael Perzl <michael@perzl.org> - 2.4.1-1
- updated to version 2.4.1

* Tue Jun 24 2008 Michael Perzl <michael@perzl.org> - 2.2.5-1
- updated to version 2.2.5

* Tue Jun 24 2008 Michael Perzl <michael@perzl.org> - 2.2.4-1
- updated to version 2.2.4

* Fri May 16 2008 Michael Perzl <michael@perzl.org> - 2.2.3-1
- updated to version 2.2.3

* Tue Apr 01 2008 Michael Perzl <michael@perzl.org> - 2.2.2-3
- linked against new version of readline

* Fri Mar 28 2008 Michael Perzl <michael@perzl.org> - 2.2.2-2
- corrected some SPEC file errors

* Mon Mar 03 2008 Michael Perzl <michael@perzl.org> - 2.2.2-1
- updated to version 2.2.2

* Wed Feb 20 2008 Michael Perzl <michael@perzl.org> - 2.2.1-1
- updated to version 2.2.1

* Mon Jan 07 2008 Michael Perzl <michael@perzl.org> - 2.2.0-2
- included both 32-bit and 64-bit shared objects

* Tue Dec 18 2007 Michael Perzl <michael@perzl.org> - 2.2.0-1
- First version for AIX5L v5.1 and higher
